axoden.volume_projections
=========================
Usually, it is enough to just import the functions from `axoden` directly.
`axoden.volume_projections` contains the full functionality used for axoden.

.. automodule:: axoden.volume_projections
    :members:
